@@ -111,7 +111,7 @@ func TestCVO_StartupAndSync(t *testing.T) {
 	// Step 1: Verify the CVO creates the initial Cluster Version object
 	//
 	client.ClearActions()
-	err := o.sync(o.queueKey())
+	err := o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -139,7 +139,7 @@ func TestCVO_StartupAndSync(t *testing.T) {
 	// Step 2: Ensure the CVO reports a status error if it has nothing to sync
 	//
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -180,7 +180,7 @@ func TestCVO_StartupAndSync(t *testing.T) {
 	desired := configv1.Update{Version: "4.0.1", Image: "image/image:1"}
 	//
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -262,7 +262,7 @@ func TestCVO_StartupAndSync(t *testing.T) {
 	// Step 4: Now that sync is complete, verify status is updated to represent image contents
 	//
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -341,7 +341,7 @@ func TestCVO_StartupAndSync(t *testing.T) {
 	// Step 6: After a reconciliation, there should be no status change because the state is the same
 	//
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -382,7 +382,7 @@ func TestCVO_StartupAndSyncUnverifiedPayload(t *testing.T) {
 	// Step 1: Verify the CVO creates the initial Cluster Version object
 	//
 	client.ClearActions()
-	err := o.sync(o.queueKey())
+	err := o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -410,7 +410,7 @@ func TestCVO_StartupAndSyncUnverifiedPayload(t *testing.T) {
 	// Step 2: Ensure the CVO reports a status error if it has nothing to sync
 	//
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -451,7 +451,7 @@ func TestCVO_StartupAndSyncUnverifiedPayload(t *testing.T) {
 	desired := configv1.Update{Version: "4.0.1", Image: "image/image:1"}
 	//
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -533,7 +533,7 @@ func TestCVO_StartupAndSyncUnverifiedPayload(t *testing.T) {
 	// Step 4: Now that sync is complete, verify status is updated to represent image contents
 	//
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -612,7 +612,7 @@ func TestCVO_StartupAndSyncUnverifiedPayload(t *testing.T) {
 	// Step 6: After a reconciliation, there should be no status change because the state is the same
 	//
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -643,7 +643,7 @@ func TestCVO_StartupAndSyncPreconditionFailing(t *testing.T) {
 	// Step 1: Verify the CVO creates the initial Cluster Version object
 	//
 	client.ClearActions()
-	err := o.sync(o.queueKey())
+	err := o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -671,7 +671,7 @@ func TestCVO_StartupAndSyncPreconditionFailing(t *testing.T) {
 	// Step 2: Ensure the CVO reports a status error if it has nothing to sync
 	//
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -712,7 +712,7 @@ func TestCVO_StartupAndSyncPreconditionFailing(t *testing.T) {
 	desired := configv1.Update{Version: "4.0.1", Image: "image/image:1"}
 	//
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -794,7 +794,7 @@ func TestCVO_StartupAndSyncPreconditionFailing(t *testing.T) {
 	// Step 4: Now that sync is complete, verify status is updated to represent image contents
 	//
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -873,7 +873,7 @@ func TestCVO_StartupAndSyncPreconditionFailing(t *testing.T) {
 	// Step 6: After a reconciliation, there should be no status change because the state is the same
 	//
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -943,7 +943,7 @@ func TestCVO_UpgradeUnverifiedPayload(t *testing.T) {
 	// Step 1: The operator should report that it is blocked on unverified content
 	//
 	client.ClearActions()
-	err := o.sync(o.queueKey())
+	err := o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -965,7 +965,7 @@ func TestCVO_UpgradeUnverifiedPayload(t *testing.T) {
 	)
 
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1013,7 +1013,7 @@ func TestCVO_UpgradeUnverifiedPayload(t *testing.T) {
 	retriever.Set(PayloadInfo{Directory: "testdata/payloadtest-2", VerificationError: payloadErr}, nil)
 	//
 	// ensure the sync worker tells the sync loop about it
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1071,7 +1071,7 @@ func TestCVO_UpgradeUnverifiedPayload(t *testing.T) {
 		},
 	)
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1168,7 +1168,7 @@ func TestCVO_UpgradeUnverifiedPayloadRetriveOnce(t *testing.T) {
 	// Step 1: The operator should report that it is blocked on unverified content
 	//
 	client.ClearActions()
-	err := o.sync(o.queueKey())
+	err := o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1190,7 +1190,7 @@ func TestCVO_UpgradeUnverifiedPayloadRetriveOnce(t *testing.T) {
 	)
 
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1238,7 +1238,7 @@ func TestCVO_UpgradeUnverifiedPayloadRetriveOnce(t *testing.T) {
 	retriever.Set(PayloadInfo{Directory: "testdata/payloadtest-2", VerificationError: payloadErr}, nil)
 	//
 	// ensure the sync worker tells the sync loop about it
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1296,7 +1296,7 @@ func TestCVO_UpgradeUnverifiedPayloadRetriveOnce(t *testing.T) {
 		},
 	)
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1420,7 +1420,7 @@ func TestCVO_UpgradePreconditionFailing(t *testing.T) {
 	// Step 1: The operator should report that it is blocked on precondition checks failing
 	//
 	client.ClearActions()
-	err := o.sync(o.queueKey())
+	err := o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1446,7 +1446,7 @@ func TestCVO_UpgradePreconditionFailing(t *testing.T) {
 	)
 
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1493,7 +1493,7 @@ func TestCVO_UpgradePreconditionFailing(t *testing.T) {
 	actual.Spec.DesiredUpdate = &copied
 	//
 	// ensure the sync worker tells the sync loop about it
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1557,7 +1557,7 @@ func TestCVO_UpgradePreconditionFailing(t *testing.T) {
 		},
 	)
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1655,7 +1655,7 @@ func TestCVO_UpgradeVerifiedPayload(t *testing.T) {
 	// Step 1: The operator should report that it is blocked on unverified content
 	//
 	client.ClearActions()
-	err := o.sync(o.queueKey())
+	err := o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1679,7 +1679,7 @@ func TestCVO_UpgradeVerifiedPayload(t *testing.T) {
 	)
 
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1727,7 +1727,7 @@ func TestCVO_UpgradeVerifiedPayload(t *testing.T) {
 	retriever.Set(PayloadInfo{Directory: "testdata/payloadtest-2", Verified: true}, nil)
 	//
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1780,7 +1780,7 @@ func TestCVO_UpgradeVerifiedPayload(t *testing.T) {
 		},
 	)
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1865,7 +1865,7 @@ func TestCVO_RestartAndReconcile(t *testing.T) {
 	// Step 1: The sync loop starts and triggers a sync, but does not update status
 	//
 	client.ClearActions()
-	err := o.sync(o.queueKey())
+	err := o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1926,7 +1926,7 @@ func TestCVO_RestartAndReconcile(t *testing.T) {
 		},
 	)
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -1971,7 +1971,7 @@ func TestCVO_RestartAndReconcile(t *testing.T) {
 		},
 	)
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -2028,7 +2028,7 @@ func TestCVO_ErrorDuringReconcile(t *testing.T) {
 	// Step 1: The sync loop starts and triggers a sync, but does not update status
 	//
 	client.ClearActions()
-	err := o.sync(o.queueKey())
+	err := o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -2070,7 +2070,7 @@ func TestCVO_ErrorDuringReconcile(t *testing.T) {
 	//         reconcile sync and verify status is not updated
 	//
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -2147,7 +2147,7 @@ func TestCVO_ErrorDuringReconcile(t *testing.T) {
 		},
 	)
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -2230,7 +2230,7 @@ func TestCVO_ParallelError(t *testing.T) {
 	// Step 1: Write initial status
 	//
 	client.ClearActions()
-	err := o.sync(o.queueKey())
+	err := o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -2313,7 +2313,7 @@ func TestCVO_ParallelError(t *testing.T) {
 	verifyAllStatus(t, worker.StatusCh())
 
 	client.ClearActions()
-	err = o.sync(o.queueKey())
+	err = o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -2350,6 +2350,7 @@ func TestCVO_ParallelError(t *testing.T) {
 }
 
 func TestCVO_VerifyInitializingPayloadState(t *testing.T) {
+	ctx := context.Background()
 	o, cvs, client, _, shutdownFn := setupCVOTest("testdata/payloadtest")
 	stopCh := make(chan struct{})
 	defer close(stopCh)
@@ -2393,7 +2394,7 @@ func TestCVO_VerifyInitializingPayloadState(t *testing.T) {
 	// Step 1: The sync loop starts and triggers a sync, but does not update status
 	//
 	client.ClearActions()
-	err := o.sync(o.queueKey())
+	err := o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -2408,6 +2409,7 @@ func TestCVO_VerifyInitializingPayloadState(t *testing.T) {
 }
 
 func TestCVO_VerifyUpdatingPayloadState(t *testing.T) {
+	ctx := context.Background()
 	o, cvs, client, _, shutdownFn := setupCVOTest("testdata/payloadtest")
 	stopCh := make(chan struct{})
 	defer close(stopCh)
@@ -2452,7 +2454,7 @@ func TestCVO_VerifyUpdatingPayloadState(t *testing.T) {
 	// Step 1: The sync loop starts and triggers a sync, but does not update status
 	//
 	client.ClearActions()
-	err := o.sync(o.queueKey())
+	err := o.sync(ctx, o.queueKey())
 	if err != nil {
 		t.Fatal(err)
 	}
